/**
  ******************************************************************************
  * @file    usbd_usr.c
  * @author  MCD Application Team
  * @version V1.1.0
  * @date    19-March-2012
  * @brief   This file includes the user application layer
  ******************************************************************************
  * @attention
  *
  * <h2><center>&copy; COPYRIGHT 2012 STMicroelectronics</center></h2>
  *
  * Licensed under MCD-ST Liberty SW License Agreement V2, (the "License");
  * You may not use this file except in compliance with the License.
  * You may obtain a copy of the License at:
  *
  *        http://www.st.com/software_license_agreement_liberty_v2
  *
  * Unless required by applicable law or agreed to in writing, software 
  * distributed under the License is distributed on an "AS IS" BASIS, 
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  * See the License for the specific language governing permissions and
  * limitations under the License.
  *
  ******************************************************************************
  */ 

/* Includes ------------------------------------------------------------------*/
#include "usbd_usr.h"
#include "usbd_ioreq.h"
#include "usbd_cdc_vcp.h"

/** @addtogroup STM32_USB_OTG_DEVICE_LIBRARY
* @{
*/

/** @defgroup USBD_USR 
* @brief    This file includes the user application layer
* @{
*/ 

/** @defgroup USBD_USR_Private_TypesDefinitions
* @{
*/ 
/**
* @}
*/ 


/** @defgroup USBD_USR_Private_Defines
* @{
*/ 
/**
* @}
*/ 


/** @defgroup USBD_USR_Private_Macros
* @{
*/ 
/**
* @}
*/ 


/** @defgroup USBD_USR_Private_Variables
* @{
*/ 

USBD_Usr_cb_TypeDef USR_cb =
{
  USBD_USR_Init,
  USBD_USR_DeviceReset,
  USBD_USR_DeviceConfigured,
  USBD_USR_DeviceSuspended,
  USBD_USR_DeviceResumed,
  
  
  USBD_USR_DeviceConnected,
  USBD_USR_DeviceDisconnected,    
};

/**
* @}
*/

/** @defgroup USBD_USR_Private_Constants
* @{
*/ 

/**
* @}
*/



/** @defgroup USBD_USR_Private_FunctionPrototypes
* @{
*/ 
/**
* @}
*/ 


/** @defgroup USBD_USR_Private_Functions
* @{
*/ 

/**
* @brief  USBD_USR_Init 
*         Called once at USB init.
* @param  None
* @retval None
*/
void USBD_USR_Init(void)
{  
	USB_CDC_STATUS=USB_CDC_DETACHED;
}

/**
* @brief  USBD_USR_DeviceReset 
*         Called after Cable connect/disconnect.
* @param  speed : device speed
* @retval None
*/
void USBD_USR_DeviceReset(uint8_t speed )
{
	USB_CDC_STATUS=USB_CDC_DETACHED;
}


/**
* @brief  USBD_USR_DeviceConfigured
*         Called after the Device is configured after
*         the cable is plugged in.
* @param  None
* @retval Staus
*/
void USBD_USR_DeviceConfigured (void)
{
	USB_CDC_STATUS=USB_CDC_CONNECTED;
}

/**
* @brief  USBD_USR_DeviceSuspended 
*         Called if connected or disconnected.
* @param  None
* @retval None
*/
void USBD_USR_DeviceSuspended(void)
{
	USB_CDC_STATUS=USB_CDC_DETACHED;
}


/**
* @brief  USBD_USR_DeviceResumed 
*         Device resume Event
* @param  None
* @retval None
*/
void USBD_USR_DeviceResumed(void)
{
	 USB_CDC_STATUS=USB_CDC_DETACHED;
}


/**
* @brief  USBD_USR_DeviceConnected
*         Cable plugged in.
* @param  None
* @retval Staus
*/
void USBD_USR_DeviceConnected (void)
{
	USB_CDC_STATUS=USB_CDC_DETACHED;
}


/**
* @brief  USBD_USR_DeviceDisonnected
*         Cable disconnected.
* @param  None
* @retval Staus
*/
void USBD_USR_DeviceDisconnected (void)
{
	USB_CDC_STATUS=USB_CDC_DETACHED;
}
/**
* @}
*/ 

/**
* @}
*/ 

/************************ (C) COPYRIGHT STMicroelectronics *****END OF FILE****/
