#include "stm32f4xx.h"
#include "delay.h"
#include "main.h"

volatile uint32_t milliseconds = 0;


void delay_init (void) {
	TIM_TimeBaseInitTypeDef  TIM_TimeBaseStructure;
	NVIC_InitTypeDef NVIC_InitStructure;

	RCC_APB1PeriphClockCmd(RCC_APB1Periph_TIM3, ENABLE);

	// Timer3: Delay Timer
	TIM_TimeBaseStructure.TIM_Period = 168;		// 1ms
	TIM_TimeBaseStructure.TIM_Prescaler = 1000-1;
	TIM_TimeBaseStructure.TIM_ClockDivision = 0;
	TIM_TimeBaseStructure.TIM_CounterMode = TIM_CounterMode_Up;
	TIM_TimeBaseInit(TIM3, &TIM_TimeBaseStructure);

	// Enable the Interrupt
	NVIC_InitStructure.NVIC_IRQChannel = TIM3_IRQn;
	NVIC_InitStructure.NVIC_IRQChannelPreemptionPriority = 0;
	NVIC_InitStructure.NVIC_IRQChannelSubPriority = 1;
	NVIC_InitStructure.NVIC_IRQChannelCmd = ENABLE;
	NVIC_Init(&NVIC_InitStructure);

	// Disable Timer3
	TIM_Cmd(TIM3, DISABLE);

	// Clear & Enable Interrupt
	TIM_ClearITPendingBit(TIM3, TIM_IT_Update);
	TIM_ITConfig(TIM3, TIM_IT_Update, ENABLE);
}

void delay_ms(uint32_t ms) {
	milliseconds = ms;

	// Set Counter Valute to 0
	TIM3->CNT = 0;
	// Enable the Timer3
	TIM3->CR1 |= TIM_CR1_CEN;

	while(milliseconds!=0) {
	}

	// Disable the Timer4
	TIM3->CR1 &= (uint16_t)(~((uint16_t)TIM_CR1_CEN));
}


inline void delay_us(uint32_t us) {
	us = us * 168 / 10;
	while(us>0) us--;
}

// Timer3: Delay Interrupt Handler
void TIM3_Up_Function(void) {
	if(milliseconds > 0) milliseconds--;
}
